Package 'scFOCAL'

Title: Integration of Drug and Single-Cell Gene Expression Signatures
Description: scFOCAL integrates small molecules transcriptional consensus signatures with single-cell gene expression data to identify cell states targeted or resistant to different perturbations. This information is leveraged by the scFOCAL combination index, which identifies synergistic combinations that maximize the discordance across a heterogenous tumor.
Authors: Zaoqu Liu [aut, cre] , Robert K. Suter [aut], Nagi G. Ayad [aut]
Maintainer: Zaoqu Liu <[email protected]>
License: file LICENSE
Version: 0.1.0
Built: 2026-06-03 06:37:15 UTC
Source: https://github.com/Zaoqu-Liu/scFOCAL

Help Index


L1000_compounds

Description

Compounds included in 2017 Release TCSs as published in Stathias et al., 2018

Usage

L1000_compounds

Format

A character vector with 1679 elements.

id

The unique identifier

name

The name associated with the id

http://www.source-of-my-data.com


L1000_genes

Description

character vector of L1000-measured genes

Usage

L1000_genes

Format

chr vector 961 elements

id

The unique identifier

name

The name associated with the id

http://www.source-of-my-data.com


LINCS.ResponseSigs

Description

2017 Release TCSs as published in Stathias et al., 2018

Usage

LINCS.ResponseSigs

Format

A data frame with 1679 rows and 961 variables:

id

The unique identifier

name

The name associated with the id

http://www.source-of-my-data.com


Launch scFOCAL

Description

Launch scFOCAL

Usage

runscFOCAL()

Examples

runscFOCAL()