| Title: | Integration of Drug and Single-Cell Gene Expression Signatures |
|---|---|
| Description: | scFOCAL integrates small molecules transcriptional consensus signatures with single-cell gene expression data to identify cell states targeted or resistant to different perturbations. This information is leveraged by the scFOCAL combination index, which identifies synergistic combinations that maximize the discordance across a heterogenous tumor. |
| Authors: | Zaoqu Liu [aut, cre] |
| Maintainer: | Zaoqu Liu <[email protected]> |
| License: | file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-03 06:37:15 UTC |
| Source: | https://github.com/Zaoqu-Liu/scFOCAL |
Compounds included in 2017 Release TCSs as published in Stathias et al., 2018
L1000_compoundsL1000_compounds
A character vector with 1679 elements.
The unique identifier
The name associated with the id
http://www.source-of-my-data.com
character vector of L1000-measured genes
L1000_genesL1000_genes
chr vector 961 elements
The unique identifier
The name associated with the id
http://www.source-of-my-data.com
2017 Release TCSs as published in Stathias et al., 2018
LINCS.ResponseSigsLINCS.ResponseSigs
A data frame with 1679 rows and 961 variables:
The unique identifier
The name associated with the id
http://www.source-of-my-data.com
Launch scFOCAL
runscFOCAL()runscFOCAL()
runscFOCAL()runscFOCAL()